from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="WorkerRunEventRatingSecondaryId")


@_attrs_define
class WorkerRunEventRatingSecondaryId:
    """
    Attributes:
        run_rid (str):
        sequence (int | Unset):
    """

    run_rid: str
    sequence: int | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        run_rid = self.run_rid

        sequence = self.sequence

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "runRid": run_rid,
            }
        )
        if sequence is not UNSET:
            field_dict["sequence"] = sequence

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        run_rid = d.pop("runRid")

        sequence = d.pop("sequence", UNSET)

        worker_run_event_rating_secondary_id = cls(
            run_rid=run_rid,
            sequence=sequence,
        )

        worker_run_event_rating_secondary_id.additional_properties = d
        return worker_run_event_rating_secondary_id

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
